@@ -11,7 +11,6 @@ from typing import TYPE_CHECKING
 
 import requests
 from invoke import task
-
 from monty import __version__ as ver
 from monty.os import cd
 
@@ -32,7 +31,7 @@ NEW_VER = datetime.datetime.today().strftime("%Y.%-m.%-d")
 def make_doc(ctx: Context) -> None:
     with cd("docs"):
         ctx.run("rm monty.*.rst", warn=True)
-        ctx.run("sphinx-apidoc --separate -P -M -d 6 -o . -f ../monty")
+        ctx.run("sphinx-apidoc --separate -P -M -d 6 -o . -f ../src/monty")
         # ctx.run("rm monty*.html", warn=True)
         # ctx.run("sphinx-build -b html . ../docs")  # HTML building.
         ctx.run("sphinx-build -M markdown . .")
@@ -133,14 +132,6 @@ def commit(ctx: Context) -> None:
 
 @task
 def set_ver(ctx: Context) -> None:
-    with open("monty/__init__.py", encoding="utf-8") as f:
-        contents = f.read()
-        contents = re.sub(
-            r"__version__ = .*\n", '__version__ = "%s"\n' % NEW_VER, contents
-        )
-
-    with open("monty/__init__.py", "w", encoding="utf-8") as f:
-        f.write(contents)
 
     with open("pyproject.toml", encoding="utf-8") as f:
         contents = f.read()
