@@ -18,6 +18,11 @@ try:
 except ImportError:
     pd = None
 
+try:
+    import pint
+except ImportError:
+    pint = None
+
 try:
     import torch
 except ImportError:
@@ -34,7 +39,6 @@ except ImportError:
     ObjectId = None
 
 import pytest
-
 from monty.json import (
     MontyDecoder,
     MontyEncoder,
@@ -46,7 +50,7 @@ from monty.json import (
 
 from . import __version__ as tests_version
 
-test_dir = os.path.join(os.path.dirname(os.path.abspath(__file__)), "test_files")
+TEST_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), "test_files")
 
 
 class GoodMSONClass(MSONable):
@@ -184,6 +188,11 @@ class ClassContainingSeries(MSONable):
         self.s = s
 
 
+class ClassContainingQuantity(MSONable):
+    def __init__(self, qty):
+        self.qty = qty
+
+
 class ClassContainingNumpyArray(MSONable):
     def __init__(self, np_a):
         self.np_a = np_a
@@ -516,6 +525,16 @@ class TestJson:
 
         jsanitize(dt, strict=True)
 
+        # test timezone aware datetime API
+        created_at = datetime.datetime.now(tz=datetime.timezone.utc)
+        data = json.loads(json.dumps(created_at, cls=MontyEncoder))
+
+        created_at_after = MontyDecoder().process_decoded(data)
+
+        assert str(created_at_after).rstrip("0") == str(created_at).rstrip(
+            "+00:00"
+        ).rstrip("0")
+
     def test_uuid(self):
         from uuid import UUID, uuid4
 
@@ -657,6 +676,24 @@ class TestJson:
         assert isinstance(obj.s["df"][0], pd.Series)
         assert list(obj.s["df"][0].a), [1, 2 == 3]
 
+    @pytest.mark.skipif(pint is None, reason="pint not present")
+    def test_pint_quantity(self):
+        ureg = pint.UnitRegistry()
+        cls = ClassContainingQuantity(qty=pint.Quantity("9.81 m/s**2"))
+
+        d = json.loads(MontyEncoder().encode(cls))
+        print(d)
+
+        assert d["qty"]["@module"] == "pint"
+        assert d["qty"]["@class"] == "Quantity"
+        assert d["qty"].get("@version") is not None
+
+        obj = ClassContainingQuantity.from_dict(d)
+        assert isinstance(obj, ClassContainingQuantity)
+        assert isinstance(obj.qty, pint.Quantity)
+        assert obj.qty.magnitude == 9.81
+        assert str(obj.qty.units) == "meter / second ** 2"
+
     def test_callable(self):
         instance = MethodSerializationClass(a=1)
         for function in [
@@ -881,7 +918,7 @@ class TestJson:
             json.loads(json.dumps(d2), cls=MontyDecoder)
 
     def test_redirect_settings_file(self):
-        data = _load_redirect(os.path.join(test_dir, "test_settings.yaml"))
+        data = _load_redirect(os.path.join(TEST_DIR, "test_settings.yaml"))
         assert data == {
             "old_module": {
                 "old_class": {"@class": "new_class", "@module": "new_module"}
